| Title: | An Interface to the PHIVOLCS Earthquake Bulletins |
|---|---|
| Description: | The Philippine Institute of Volcanology and Seismology (PHIVOLCS) maintains the National Earthquake Monitoring and Information which aims to provide accurate and timely information on significant earthquakes and tsunami events that may significantly impact the Philippines and ensures the accessibility and integrity of earthquake data. This package provides an interface to this information with functions that harvests, processes, and structures information from the frequent earthquake bulletins released by PHIVOLCS into machine-readable versions. |
| Authors: | Ernest Guevarra [aut, cre] (ORCID: <https://orcid.org/0000-0002-4887-4415>) |
| Maintainer: | Ernest Guevarra <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.0.0.9001 |
| Built: | 2026-05-15 09:00:56 UTC |
| Source: | https://github.com/panukatan/lindol |
Build URLs for specific PHIVOLCS earthquake bulletin summaries
eq_build_url( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL )eq_build_url( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL )
.url |
Base URL for PHIVOLCS earthquake bulletin summaries. |
.year |
A vector for year (in YYYY format) for which earthquake bulletins are to be retrieved. The earliest year that can be specified is 2018. If set to NULL (default), all years starting from 2018 to present year are used. |
.month |
A vector for month for which earthquake bulletins are to be retrieved. This can be set as either an integer index (1 for January) or abbreviation (Jan for January) for full name. If set to NULL (default), all months are used. |
A vector of URLs based on given .year and .month
eq_build_url()eq_build_url()
Retrieve earthquake information data from PHIVOLCS bulletins
eq_data_summary( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL, latest = TRUE ) eq_data_bulletin( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL, latest = TRUE, parallel = FALSE, cores = 2 )eq_data_summary( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL, latest = TRUE ) eq_data_bulletin( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL, latest = TRUE, parallel = FALSE, cores = 2 )
.url |
Base URL for PHIVOLCS earthquake bulletins. |
.year |
A vector for year (in YYYY format) for which earthquake bulletins are to be retrieved. The earliest year that can be specified is 2018. If set to NULL (default), all years starting from 2018 to present year are used. |
.month |
A vector for month for which earthquake bulletins are to be retrieved. This can be set as either an integer index (1 for January) or abbreviation (Jan for January) for full name. If set to NULL (default), all months are used. |
latest |
Logical. Should the latest table of earthquake information be
retrieved? Only evaluated if |
parallel |
Logical. Should the function use parallelisation? Default to FALSE. |
cores |
The number of computer cores to use or number of child processes to be run simultaneously. Default to one less than the available number of cores on current machine. |
A tibble of processed earthquake data.
eq_data_summary()eq_data_summary()
Retrieve raw information from PHIVOLCS earthquake information bulletins
eq_get_bulletin(.url) eq_get_bulletins(.url)eq_get_bulletin(.url) eq_get_bulletins(.url)
.url |
A character value or vector of values for PHIVOLCS earthquake information bulletins |
A tibble of earthquake information from PHIVOLCS bulletins
.url <- eq_build_url(.year = 2023, .month = "January") urls <- eq_get_bulletin_links(.url) eq_get_bulletins(urls[1:3]).url <- eq_build_url(.year = 2023, .month = "January") urls <- eq_get_bulletin_links(.url) eq_get_bulletins(urls[1:3])
Get URLs for detailed PHIVOLCS earthquake information bulletins
eq_get_bulletin_link(.url) eq_get_bulletin_links(.url)eq_get_bulletin_link(.url) eq_get_bulletin_links(.url)
.url |
Base URL or monthly URL for PHIVOLCS earthquake bulletins. This
is usually produced through a call to |
A character vector of URLs for detailed PHIVOLCS earthquake information bulletins.
.url <- eq_build_url(.year = 2020, .month = "January") eq_get_bulletin_links(.url).url <- eq_build_url(.year = 2020, .month = "January") eq_get_bulletin_links(.url)
Get earthquake monitoring information from PHIVOLCS earthquake bulletin HTMLs
eq_get_tables( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL, latest = TRUE ) eq_get_table(.url)eq_get_tables( .url = "https://earthquake.phivolcs.dost.gov.ph/", .year = NULL, .month = NULL, latest = TRUE ) eq_get_table(.url)
.url |
Base URL for PHIVOLCS earthquake bulletins. |
.year |
A vector for year (in YYYY format) for which earthquake bulletins are to be retrieved. The earliest year that can be specified is 2018. If set to NULL (default), all years starting from 2018 to present year are used. |
.month |
A vector for month for which earthquake bulletins are to be retrieved. This can be set as either an integer index (1 for January) or abbreviation (Jan for January) for full name. If set to NULL (default), all months are used. |
latest |
Logical. Should the latest table of earthquake information be
retrieved? Only evaluated if |
A list of tibble/s of raw earthquake information from PHIVOLCS.
eq_get_tables()eq_get_tables()
Process earthquake information from PHIVOLCS bulletins
eq_process_bulletins(eq_df)eq_process_bulletins(eq_df)
eq_df |
A tibble of earthquake information from PHIVOLCS bulletins
retrieved using |
A tibble of processed earthquake information from PHIVOLCS bulletins.
.url <- eq_build_url(.year = 2018, .month = "January") urls <- eq_get_bulletin_links(.url) eq_get_bulletins(urls[1:3]) |> eq_process_bulletins().url <- eq_build_url(.year = 2018, .month = "January") urls <- eq_get_bulletin_links(.url) eq_get_bulletins(urls[1:3]) |> eq_process_bulletins()
Process tabular data extracted from bulletins
eq_process_tables(eq_data_list) eq_process_table(eq_data_list)eq_process_tables(eq_data_list) eq_process_table(eq_data_list)
eq_data_list |
A list of tibble/s of raw earthquake data extracted from
PHIVOLCS earthquake information monitoring HTMLs using |
A tibble of processed earthquake data summaries.
eq_tab <- eq_get_tables() eq_process_tables(eq_tab)eq_tab <- eq_get_tables() eq_process_tables(eq_tab)